%High Pressure Contour

close all

position = [100 100 1280 720];
set(0, 'DefaultFigurePosition', position);
hgtfile = sprintf('hgt.nc');
hgtraw = nc_varget(hgtfile,'hgt');
hgttime = nc_varget(hgtfile,'time');
vwindfile = sprintf('vwind.nc');
vraw = nc_varget(vwindfile,'vwnd');

%Squeeze
hgt_ = squeeze(hgtraw(1:end,1,13:29,93:129));
v_ = squeeze(vraw(1:end,1,24:29,105:112));

strt = 209;
fin = 249;
frame = 0;

for k = strt:fin
    
    %TIME
    d = 2012;
    month = rem(k,12);
    if month == 0
        month = 12;
    end
    
    hgt = squeeze(hgt_(k,fliplr(1:end),:)); %lat 20 - 60N Lon 230-320E 500mb
    v = squeeze(v_(k,fliplr(1:end),:)); %lat 20 - 32.5N Lon 260-277.5E 700mb
    
    %GEOPOTENTIAL HEIGHT
    colormap(jet); %use default color scheme for geopotential height contours
    [C,h] = contour(-130:2.5:-40, 20:2.5:60, hgt, 30);
    caxis([5600 5900])
    hcb1 = cbfreeze(colorbar('horiz'));
    %Colorbar title
    set(get(hcb1,'Title'),'String','Geopotential Heigh @ 500mb (m)')
    locate = get(hcb1,'title');
    pos = get(locate,'position'); 
    pos(1,2) = pos(1,2) - 2.5;
    set(locate,'pos', pos);
    freezeColors
    hold on
    
    %VWIND
    colormap(cool);
    [C,h] = contourf(-100:2.5:-82.5, 20:2.5:32.5, v, 'LevelStep', 0.05);
    set(h,'linecolor','none');
    caxis([-4 4]);
    freezeColors
    hold on
    hcb2 = cbfreeze(colorbar('horiz'));
    %Colorbar title
    set(get(hcb2,'Title'),'String','Meridional Wind @ 700mb (m/s) [> 0 = Northward & < 0 Southward]')    
    locate = get(hcb2,'title');
    pos = get(locate,'position'); 
    pos(1,2) = pos(1,2) - 2.5;
    set(locate,'pos', pos);
    
    %GRAPHICS
    title(['Geopotential Height & Gulf Coast Meridional Wind: Day ' num2str(k) ' of ' num2str(d)])
    geoshow('landareas.shp', 'FaceColor', [.7 .5 0]);
    hold on
    F(k) = getframe(gcf);
    
    export_fig(gcf,'-nocrop', ['drought',sprintf('%03d',frame),'.png'])
    %saveas(gcf, ['drought',sprintf('%03d',frame),'.png'])
    frame = frame + 1;
    
    %Clear all frames besides the last
    if k < fin
        clf
    end
    
end

